aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/receipts.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/csapi/receipts.h')
-rw-r--r--lib/csapi/receipts.h59
1 files changed, 34 insertions, 25 deletions
diff --git a/lib/csapi/receipts.h b/lib/csapi/receipts.h
index 47e2f3c7..98bc5004 100644
--- a/lib/csapi/receipts.h
+++ b/lib/csapi/receipts.h
@@ -6,30 +6,39 @@
#include "jobs/basejob.h"
-#include <QtCore/QJsonObject>
+namespace Quotient {
-namespace QMatrixClient
-{
- // Operations
+/*! \brief Send a receipt for the given event ID.
+ *
+ * This API updates the marker for the given receipt type to the event ID
+ * specified.
+ */
+class QUOTIENT_API PostReceiptJob : public BaseJob {
+public:
+ /*! \brief Send a receipt for the given event ID.
+ *
+ * \param roomId
+ * The room in which to send the event.
+ *
+ * \param receiptType
+ * The type of receipt to send. This can also be `m.fully_read` as an
+ * alternative to
+ * [`/read_makers`](/client-server-api/#post_matrixclientv3roomsroomidread_markers).
+ *
+ * Note that `m.fully_read` does not appear under `m.receipt`: this
+ * endpoint effectively calls `/read_markers` internally when presented with
+ * a receipt type of `m.fully_read`.
+ *
+ * \param eventId
+ * The event ID to acknowledge up to.
+ *
+ * \param receipt
+ * Extra receipt information to attach to `content` if any. The
+ * server will automatically set the `ts` field.
+ */
+ explicit PostReceiptJob(const QString& roomId, const QString& receiptType,
+ const QString& eventId,
+ const QJsonObject& receipt = {});
+};
- /// Send a receipt for the given event ID.
- ///
- /// This API updates the marker for the given receipt type to the event ID
- /// specified.
- class PostReceiptJob : public BaseJob
- {
- public:
- /*! Send a receipt for the given event ID.
- * \param roomId
- * The room in which to send the event.
- * \param receiptType
- * The type of receipt to send.
- * \param eventId
- * The event ID to acknowledge up to.
- * \param receipt
- * Extra receipt information to attach to ``content`` if any. The
- * server will automatically set the ``ts`` field.
- */
- explicit PostReceiptJob(const QString& roomId, const QString& receiptType, const QString& eventId, const QJsonObject& receipt = {});
- };
-} // namespace QMatrixClient
+} // namespace Quotient